@@ -592,7 +592,7 @@ class HamsterApplet(object):
 
     def on_activity_entered(self, component):
         """fires, when user writes activity by hand"""
-        activity_name = component.get_text()
+        activity_name = component.get_text().decode('utf8', 'replace')
         
         if activity_name == "":
             return
@@ -617,7 +617,9 @@ class HamsterApplet(object):
         
         
     def on_windows_keys(self, tree, event_key):
-        if (event_key.keyval == gtk.keysyms.Escape):
+        if (event_key.keyval == gtk.keysyms.Escape
+          or (event_key.keyval == gtk.keysyms.w 
+              and event_key.state & gtk.gdk.CONTROL_MASK)):
             dispatcher.dispatch('panel_visible', False)
             return True
         return False
