@@ -1,8 +1,5 @@
 DATA_DIR = "/usr//share"
 LIB_DIR = "/usr//lib"
-VERSION = "2.25.90"
+VERSION = "2.25.91"
 PACKAGE = "hamster-applet"
 PYTHONDIR = "/usr//lib/python2.5/site-packages"
-
-import sys, os.path 
-sys.path.append(".libs") 
\ No newline at end of file
